AnonymousAuthenticator class
An authenticator that treats every caller as anonymous (returns null).
The default — authentication is opt-in.
- Implemented types
Constructors
- AnonymousAuthenticator()
-
Creates an anonymous authenticator.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
HubRequest request) → Future< Principal?> -
Authenticates
request. See the class contract for the return/throw semantics.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited