ProtocolRule class

Matches when the request protocol is one of protocols.

Inheritance

Constructors

ProtocolRule(Set<TransportProtocol> protocols)
Creates a protocol rule accepting protocols.
const
ProtocolRule.secure()
Matches TLS protocols (https, wss).
ProtocolRule.webSocket()
Matches WebSocket protocols (ws, wss).

Properties

hashCode int
The hash code for this object.
no setterinherited
protocols Set<TransportProtocol>
The set of accepted protocols.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specificity int
A relative measure of how specific this rule is, used as a tie-breaker among matching routes of equal priority. Higher is more specific.
no setteroverride

Methods

and(RouteRule other) RouteRule
A rule matching when both this and other match.
inherited
matches(RouteContext context) bool
Whether this rule matches context.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() RouteRule
A rule matching when this rule does not match.
inherited
or(RouteRule other) RouteRule
A rule matching when either this or other matches.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator &(RouteRule other) RouteRule
Operator form of and.
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator |(RouteRule other) RouteRule
Operator form of or.
inherited
operator ~() RouteRule
Operator form of not.
inherited