ProxyException class
A reverse-proxy operation failed (upstream unreachable, upstream returned a transport error, WebSocket upgrade to the upstream failed, ...).
- Inheritance
-
- Object
- HubException
- ProxyException
Constructors
- ProxyException({String code = ErrorCodes.badGateway, required String message})
-
Creates a proxy failure with
messageand an optional specificcode.const
Properties
- code → String
-
Stable, machine-readable error code (see ErrorCodes).
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable description of the failure.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
HTTP status code the pipeline should respond with.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited