SingleUpstream class

An Upstream that always returns the same base URI.

Implemented types

Constructors

SingleUpstream(Uri base)
Creates a single-target upstream.
const

Properties

base Uri
The fixed base URI.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
select(HubRequest request) Uri
Selects the base URI for request.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited