NodeState enum

The lifecycle state of a NodeRuntime.

Inheritance
Available extensions

Values

disconnected → const NodeState

Not connected.

connecting → const NodeState

Establishing the control connection.

registering → const NodeState

Connected; awaiting registration acknowledgement.

ready → const NodeState

Registered and serving.

backoff → const NodeState

Waiting to reconnect after a drop.

stopped → const NodeState

Stopped by the caller.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NodeState>
A constant List of the values in this enum, in order of their declaration.