HostPatternRule class
Matches a regular expression against the host (or its part).
Use this for host/domain routing beyond exact and *. wildcard matches —
e.g. HostPatternRule(RegExp(r'^(dev|stg)\.example\.com$')) or match a
subdomain shape with part: HostPart.subdomain. Combine with a PathRule
via & to route by host and path prefix.
Constructors
- HostPatternRule(RegExp pattern, {HostPart part = HostPart.host})
-
Creates a host-pattern rule.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- part → HostPart
-
Which part of the host to match.
final
- pattern → RegExp
-
The pattern matched against the selected host part.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specificity → int
-
A relative measure of how specific this rule is, used as a tie-breaker
among matching routes of equal priority. Higher is more specific.
no setteroverride
Methods
-
and(
RouteRule other) → RouteRule -
A rule matching when both this and
othermatch.inherited -
matches(
RouteContext context) → bool -
Whether this rule matches
context.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
not(
) → RouteRule -
A rule matching when this rule does not match.
inherited
-
or(
RouteRule other) → RouteRule -
A rule matching when either this or
othermatches.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator &(
RouteRule other) → RouteRule -
Operator form of and.
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator |(
RouteRule other) → RouteRule -
Operator form of or.
inherited
-
operator ~(
) → RouteRule -
Operator form of not.
inherited