NodeQuery class final
Node → hub: discover peer nodes matching a capability/label filter.
- Inheritance
-
- Object
- NodeControlMessage
- NodeQuery
- Annotations
-
- @immutable
Constructors
Properties
- capability → String?
-
Required capability, if any.
final
-
filter
→ Map<
String, dynamic> -
An application-defined filter, interpreted hub-side by a
NodeMatcher.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
→ Map<
String, String> -
Required labels (all must match).
final
- requestId → String
-
Correlation id echoed in the NodeQueryResult.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The wire type discriminator (the
tenvelope field).no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
The message body (without the
tdiscriminator).override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited